'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var dayjs = _interopDefault(require('dayjs'));
var crypto = require('crypto');
var axios = _interopDefault(require('axios'));

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;

  _setPrototypeOf(subClass, superClass);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

var SigningRequest = /*#__PURE__*/function () {
  function SigningRequest(_ref) {
    var endpoint = _ref.endpoint,
        version = _ref.version,
        method = _ref.method,
        payload = _ref.payload,
        key = _ref.key,
        secret = _ref.secret;
    this._nonce = dayjs().unix();
    this._version = version != null ? version : 'v3';
    this._method = method || '';
    this._payload = payload != null ? payload : {};
    this._key = key;
    this._secret = secret;
    this._endpoint = endpoint != null ? endpoint : '';
    this._bufferSigning = '';
  }

  var _proto = SigningRequest.prototype;

  _proto.isEmpty = function isEmpty(obj) {
    return Object.keys(obj).length === 0;
  };

  _proto.serializePayload = function serializePayload() {
    return JSON.stringify(this._payload);
  };

  _proto.createSigningRequest = function createSigningRequest() {
    this._nonce = dayjs().unix();
    this._bufferSigning = "" + this._nonce + this._method + "/" + this._version + "/" + this._endpoint;

    if (!this.isEmpty(this._payload)) {
      var serializedPayload = this.serializePayload();
      this._bufferSigning = this._bufferSigning.concat(serializedPayload);
    }

    return crypto.createHmac('sha256', this._secret).update(this._bufferSigning).digest('hex');
  };

  _proto.getHeader = function getHeader() {
    var signingRequest = this.createSigningRequest();
    return "Bitso " + this._key + ":" + this._nonce + ":" + signingRequest;
  };

  _createClass(SigningRequest, [{
    key: "payload",
    set: function set(payload) {
      this._payload = payload;
    }
  }, {
    key: "endpoint",
    set: function set(endpoint) {
      this._endpoint = endpoint;
    }
  }, {
    key: "method",
    set: function set(method) {
      this._method = method;
    }
  }]);

  return SigningRequest;
}();

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var runtime_1 = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var runtime = (function (exports) {

  var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var undefined$1; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  function define(obj, key, value) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
    return obj[key];
  }
  try {
    // IE 8 has a broken Object.defineProperty that only works on DOM objects.
    define({}, "");
  } catch (err) {
    define = function(obj, key, value) {
      return obj[key] = value;
    };
  }

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  exports.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  define(IteratorPrototype, iteratorSymbol, function () {
    return this;
  });

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = GeneratorFunctionPrototype;
  define(Gp, "constructor", GeneratorFunctionPrototype);
  define(GeneratorFunctionPrototype, "constructor", GeneratorFunction);
  GeneratorFunction.displayName = define(
    GeneratorFunctionPrototype,
    toStringTagSymbol,
    "GeneratorFunction"
  );

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      define(prototype, method, function(arg) {
        return this._invoke(method, arg);
      });
    });
  }

  exports.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  exports.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      define(genFun, toStringTagSymbol, "GeneratorFunction");
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  exports.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator, PromiseImpl) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return PromiseImpl.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return PromiseImpl.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration.
          result.value = unwrapped;
          resolve(result);
        }, function(error) {
          // If a rejected Promise was yielded, throw the rejection back
          // into the async generator function so it can be handled there.
          return invoke("throw", error, resolve, reject);
        });
      }
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new PromiseImpl(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);
  define(AsyncIterator.prototype, asyncIteratorSymbol, function () {
    return this;
  });
  exports.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
    if (PromiseImpl === void 0) PromiseImpl = Promise;

    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList),
      PromiseImpl
    );

    return exports.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined$1) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        // Note: ["return"] must be used for ES3 parsing compatibility.
        if (delegate.iterator["return"]) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined$1;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined$1;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  define(Gp, toStringTagSymbol, "Generator");

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  define(Gp, iteratorSymbol, function() {
    return this;
  });

  define(Gp, "toString", function() {
    return "[object Generator]";
  });

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  exports.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined$1;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  exports.values = values;

  function doneResult() {
    return { value: undefined$1, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined$1;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined$1;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined$1;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined$1;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined$1;
      }

      return ContinueSentinel;
    }
  };

  // Regardless of whether this script is executing as a CommonJS module
  // or not, return the runtime object so that we can declare the variable
  // regeneratorRuntime in the outer scope, which allows this module to be
  // injected easily by `bin/regenerator --include-runtime script.js`.
  return exports;

}(
  // If this script is executing as a CommonJS module, use module.exports
  // as the regeneratorRuntime namespace. Otherwise create a new empty
  // object. Either way, the resulting object will be used to initialize
  // the regeneratorRuntime variable at the top of this file.
   module.exports 
));

try {
  regeneratorRuntime = runtime;
} catch (accidentalStrictMode) {
  // This module should not be running in strict mode, so the above
  // assignment should always work unless something is misconfigured. Just
  // in case runtime.js accidentally runs in strict mode, in modern engines
  // we can explicitly access globalThis. In older engines we can escape
  // strict mode using a global Function call. This could conceivably fail
  // if a Content Security Policy forbids using Function, but in that case
  // the proper solution is to fix the accidental strict mode problem. If
  // you've misconfigured your bundler to force strict mode and applied a
  // CSP to forbid Function, and you're not willing to fix either of those
  // problems, please detail your unique predicament in a GitHub issue.
  if (typeof globalThis === "object") {
    globalThis.regeneratorRuntime = runtime;
  } else {
    Function("r", "regeneratorRuntime = r")(runtime);
  }
}
});

var HttpClient = /*#__PURE__*/function () {
  function HttpClient(baseUrl, headers, timeout) {
    this.baseUrl = baseUrl;
    this.headers = headers;
    this.timeout = timeout;
    this._httpClient = this.getInstance();
  }

  var _proto = HttpClient.prototype;

  _proto.openConnection = function openConnection() {
    var _this$timeout, _this$headers;

    return axios.create({
      baseURL: this.baseUrl,
      timeout: (_this$timeout = this.timeout) != null ? _this$timeout : 5000,
      headers: (_this$headers = this.headers) != null ? _this$headers : {}
    });
  };

  _proto.setAuthToken = function setAuthToken(token) {
    this._httpClient.defaults.headers.common['Authorization'] = 'Bearer ' + token;
  };

  _proto.setHeaders = function setHeaders(customHeaders) {
    Object.assign(this._httpClient.defaults.headers, customHeaders);
  };

  _proto.setAPIBase = function setAPIBase(url) {
    this._httpClient.defaults['baseURL'] = url;
  };

  _proto.getInstance = function getInstance() {
    return this._httpClient ? this._httpClient : this.openConnection();
  };

  return HttpClient;
}();

var AccountAPI = /*#__PURE__*/function (_HttpClient) {
  _inheritsLoose(AccountAPI, _HttpClient);

  function AccountAPI(_ref, signRequest) {
    var _this;

    var version = _ref.version,
        test = _ref.test;
    _this = _HttpClient.call(this, test ? "https://sandbox.bitso.com"
    /* TEST */
    : "https://api.bitso.com"
    /* PROD */
    + '/' + version + '/') || this;

    _this._initializeRequestInterceptor = function () {
      _this._httpClient.interceptors.request.use(_this._handleRequest, _this._handleError);
    };

    _this._handleRequest = function (config) {
      config.headers['Authorization'] = _this._signReq.getHeader();
      return config;
    };

    _this._handleResponse = function (_ref2) {
      var data = _ref2.data;
      return data.payload;
    };

    _this._handleError = function (error) {
      return Promise.reject(error);
    };

    _this._initializeResponseInterceptor();

    _this._initializeRequestInterceptor();

    _this._signReq = signRequest;
    return _this;
  }

  var _proto = AccountAPI.prototype;

  _proto.getAccountBalance = /*#__PURE__*/function () {
    var _getAccountBalance = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee() {
      var endpoint;
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              endpoint = 'balance';
              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpoint;
              _context.next = 6;
              return this._httpClient.get(endpoint);

            case 6:
              return _context.abrupt("return", _context.sent);

            case 7:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function getAccountBalance() {
      return _getAccountBalance.apply(this, arguments);
    }

    return getAccountBalance;
  }();

  _proto.getAccountStatus = /*#__PURE__*/function () {
    var _getAccountStatus = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2() {
      var endpoint;
      return runtime_1.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              endpoint = 'account_status';
              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpoint;
              _context2.next = 6;
              return this._httpClient.get(endpoint);

            case 6:
              return _context2.abrupt("return", _context2.sent);

            case 7:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, this);
    }));

    function getAccountStatus() {
      return _getAccountStatus.apply(this, arguments);
    }

    return getAccountStatus;
  }();

  _proto.getFees = /*#__PURE__*/function () {
    var _getFees = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3() {
      var endpoint;
      return runtime_1.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              endpoint = 'fees';
              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpoint;
              _context3.next = 6;
              return this._httpClient.get(endpoint);

            case 6:
              return _context3.abrupt("return", _context3.sent);

            case 7:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, this);
    }));

    function getFees() {
      return _getFees.apply(this, arguments);
    }

    return getFees;
  }();

  _proto._initializeResponseInterceptor = function _initializeResponseInterceptor() {
    this._httpClient.interceptors.response.use(this._handleResponse, this._handleError);
  };

  return AccountAPI;
}(HttpClient);

var FundsAPI = /*#__PURE__*/function (_HttpClient) {
  _inheritsLoose(FundsAPI, _HttpClient);

  function FundsAPI(_ref, signRequest) {
    var _this;

    var version = _ref.version,
        test = _ref.test;
    _this = _HttpClient.call(this, test ? "https://sandbox.bitso.com"
    /* TEST */
    : "https://api.bitso.com"
    /* PROD */
    + '/' + version + '/') || this;

    _this._initializeRequestInterceptor = function () {
      _this._httpClient.interceptors.request.use(_this._handleRequest, _this._handleError);
    };

    _this._handleRequest = function (config) {
      config.headers['Authorization'] = _this._signReq.getHeader();
      return config;
    };

    _this._handleResponse = function (_ref2) {
      var data = _ref2.data;
      return data.payload;
    };

    _this._handleError = function (error) {
      return Promise.reject(error);
    };

    _this._initializeResponseInterceptor();

    _this._initializeRequestInterceptor();

    _this._signReq = signRequest;
    return _this;
  }

  var _proto = FundsAPI.prototype;

  _proto.fundingDestination = /*#__PURE__*/function () {
    var _fundingDestination = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(fund_currency) {
      var endpoint;
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              endpoint = 'funding_destination';
              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpoint;
              _context.next = 6;
              return this._httpClient.get(endpoint + '?fund_currency=' + fund_currency);

            case 6:
              return _context.abrupt("return", _context.sent);

            case 7:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function fundingDestination(_x) {
      return _fundingDestination.apply(this, arguments);
    }

    return fundingDestination;
  }();

  _proto._initializeResponseInterceptor = function _initializeResponseInterceptor() {
    this._httpClient.interceptors.response.use(this._handleResponse, this._handleError);
  };

  return FundsAPI;
}(HttpClient);

var TradeAPI = /*#__PURE__*/function (_HttpClient) {
  _inheritsLoose(TradeAPI, _HttpClient);

  function TradeAPI(_ref, signRequest) {
    var _this;

    var version = _ref.version,
        test = _ref.test;
    _this = _HttpClient.call(this, test ? "https://sandbox.bitso.com"
    /* TEST */
    : "https://api.bitso.com"
    /* PROD */
    + '/' + version + '/') || this;

    _this._initializeRequestInterceptor = function () {
      _this._httpClient.interceptors.request.use(_this._handleRequest, _this._handleError);
    };

    _this._handleRequest = function (config) {
      config.headers['Authorization'] = _this._signReq.getHeader();
      console.log(_this._signReq.getHeader());
      return config;
    };

    _this._handleResponse = function (_ref2) {
      var data = _ref2.data;
      return data.payload;
    };

    _this._handleError = function (error) {
      return Promise.reject(error);
    };

    _this._signReq = signRequest;

    _this._initializeResponseInterceptor();

    _this._initializeRequestInterceptor();

    return _this;
  }

  var _proto = TradeAPI.prototype;

  _proto.getOpenOrders = /*#__PURE__*/function () {
    var _getOpenOrders = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(_ref3) {
      var book, marker, sort, limit, endpoint, queryParams;
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              book = _ref3.book, marker = _ref3.marker, sort = _ref3.sort, limit = _ref3.limit;
              endpoint = 'open_orders';
              queryParams = new URLSearchParams();
              if (book) queryParams.set('book', book);
              if (marker) queryParams.set('marker', marker);
              if (sort) queryParams.set('sort', sort);
              if (limit) queryParams.set('limit', limit);
              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpoint + '?' + queryParams;
              _context.next = 12;
              return this._httpClient.get(endpoint + '?' + queryParams);

            case 12:
              return _context.abrupt("return", _context.sent);

            case 13:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function getOpenOrders(_x) {
      return _getOpenOrders.apply(this, arguments);
    }

    return getOpenOrders;
  }();

  _proto.cancelOrder = /*#__PURE__*/function () {
    var _cancelOrder = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(_ref4) {
      var oid, oids, origin_ids, endpoint, endpointFinal, queryParams, _queryParams;

      return runtime_1.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              oid = _ref4.oid, oids = _ref4.oids, origin_ids = _ref4.origin_ids;
              endpoint = 'orders';
              endpointFinal = endpoint;

              if (oid) {
                endpointFinal = endpointFinal.concat('/' + oid);
              } else if (oids) {
                queryParams = new URLSearchParams();
                queryParams.set('oids', oids.join(','));
                endpointFinal = endpointFinal.concat('?' + queryParams);
              } else if (origin_ids) {
                _queryParams = new URLSearchParams();

                _queryParams.set('origin_ids', origin_ids.join(','));

                endpointFinal = endpointFinal.concat('?' + _queryParams);
              } else {
                endpointFinal = endpointFinal.concat('/all');
              }

              this._signReq.method = 'DELETE';
              this._signReq.payload = {};
              this._signReq.endpoint = endpointFinal;
              _context2.next = 9;
              return this._httpClient["delete"](endpointFinal);

            case 9:
              return _context2.abrupt("return", _context2.sent);

            case 10:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, this);
    }));

    function cancelOrder(_x2) {
      return _cancelOrder.apply(this, arguments);
    }

    return cancelOrder;
  }();

  _proto.placeOrder = /*#__PURE__*/function () {
    var _placeOrder = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3(orderPayload) {
      var endpoint;
      return runtime_1.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              endpoint = 'orders';
              this._signReq.method = 'POST';
              this._signReq.payload = orderPayload;
              this._signReq.endpoint = endpoint;
              console.log(this._signReq.getHeader());
              _context3.next = 7;
              return this._httpClient.post(endpoint, orderPayload);

            case 7:
              return _context3.abrupt("return", _context3.sent);

            case 8:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, this);
    }));

    function placeOrder(_x3) {
      return _placeOrder.apply(this, arguments);
    }

    return placeOrder;
  }();

  _proto.placeMarketBuyOrder = /*#__PURE__*/function () {
    var _placeMarketBuyOrder = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee4(currency, quantity) {
      var request;
      return runtime_1.wrap(function _callee4$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              request = {
                book: currency,
                side: 'buy',
                type: 'market',
                minor: quantity
              };
              _context4.next = 3;
              return this.placeOrder(request);

            case 3:
              return _context4.abrupt("return", _context4.sent);

            case 4:
            case "end":
              return _context4.stop();
          }
        }
      }, _callee4, this);
    }));

    function placeMarketBuyOrder(_x4, _x5) {
      return _placeMarketBuyOrder.apply(this, arguments);
    }

    return placeMarketBuyOrder;
  }();

  _proto.placeMarketSellOrder = /*#__PURE__*/function () {
    var _placeMarketSellOrder = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee5(currency, quantity) {
      var request;
      return runtime_1.wrap(function _callee5$(_context5) {
        while (1) {
          switch (_context5.prev = _context5.next) {
            case 0:
              request = {
                book: currency,
                side: 'sell',
                type: 'market',
                major: quantity
              };
              _context5.next = 3;
              return this.placeOrder(request);

            case 3:
              return _context5.abrupt("return", _context5.sent);

            case 4:
            case "end":
              return _context5.stop();
          }
        }
      }, _callee5, this);
    }));

    function placeMarketSellOrder(_x6, _x7) {
      return _placeMarketSellOrder.apply(this, arguments);
    }

    return placeMarketSellOrder;
  }();

  _proto.placeLimitSellOrder = /*#__PURE__*/function () {
    var _placeLimitSellOrder = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee6(_ref5) {
      var currency, limit_price, quantity, request;
      return runtime_1.wrap(function _callee6$(_context6) {
        while (1) {
          switch (_context6.prev = _context6.next) {
            case 0:
              currency = _ref5.currency, limit_price = _ref5.limit_price, quantity = _ref5.quantity;
              request = {
                book: currency,
                side: 'sell',
                type: 'limit',
                price: limit_price,
                major: quantity
              };
              _context6.next = 4;
              return this.placeOrder(request);

            case 4:
              return _context6.abrupt("return", _context6.sent);

            case 5:
            case "end":
              return _context6.stop();
          }
        }
      }, _callee6, this);
    }));

    function placeLimitSellOrder(_x8) {
      return _placeLimitSellOrder.apply(this, arguments);
    }

    return placeLimitSellOrder;
  }();

  _proto.placeLimitBuyOrder = /*#__PURE__*/function () {
    var _placeLimitBuyOrder = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee7(_ref6) {
      var currency, limit_price, quantity, request;
      return runtime_1.wrap(function _callee7$(_context7) {
        while (1) {
          switch (_context7.prev = _context7.next) {
            case 0:
              currency = _ref6.currency, limit_price = _ref6.limit_price, quantity = _ref6.quantity;
              request = {
                book: currency,
                side: 'sell',
                type: 'limit',
                price: limit_price,
                minor: quantity
              };
              _context7.next = 4;
              return this.placeOrder(request);

            case 4:
              return _context7.abrupt("return", _context7.sent);

            case 5:
            case "end":
              return _context7.stop();
          }
        }
      }, _callee7, this);
    }));

    function placeLimitBuyOrder(_x9) {
      return _placeLimitBuyOrder.apply(this, arguments);
    }

    return placeLimitBuyOrder;
  }();

  _proto.getUserTrades = /*#__PURE__*/function () {
    var _getUserTrades = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee8(_ref7) {
      var oid, origin_id, endpoint, queryParams, endpointFinal;
      return runtime_1.wrap(function _callee8$(_context8) {
        while (1) {
          switch (_context8.prev = _context8.next) {
            case 0:
              oid = _ref7.oid, origin_id = _ref7.origin_id;
              endpoint = 'user_trades';
              queryParams = new URLSearchParams();
              if (oid) queryParams.set('oid', oid);
              if (origin_id) queryParams.set('origin_id', origin_id);
              endpointFinal = endpoint + '/';

              if (queryParams) {
                endpointFinal = endpoint.concat('?' + queryParams);
              }

              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpointFinal;
              _context8.next = 12;
              return this._httpClient.get(endpointFinal);

            case 12:
              return _context8.abrupt("return", _context8.sent);

            case 13:
            case "end":
              return _context8.stop();
          }
        }
      }, _callee8, this);
    }));

    function getUserTrades(_x10) {
      return _getUserTrades.apply(this, arguments);
    }

    return getUserTrades;
  }();

  _proto.getOrderTrades = /*#__PURE__*/function () {
    var _getOrderTrades = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee9(_ref8) {
      var origin_id, oid, endpoint, queryParams, endpointFinal;
      return runtime_1.wrap(function _callee9$(_context9) {
        while (1) {
          switch (_context9.prev = _context9.next) {
            case 0:
              origin_id = _ref8.origin_id, oid = _ref8.oid;
              endpoint = 'order_trades';
              queryParams = new URLSearchParams();
              if (oid) queryParams.set('oid', oid);
              if (origin_id) queryParams.set('origin_id', origin_id);
              endpointFinal = endpoint + '/';

              if (queryParams) {
                endpointFinal = endpoint.concat('?' + queryParams);
              }

              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpointFinal;
              _context9.next = 12;
              return this._httpClient.get(endpointFinal);

            case 12:
              return _context9.abrupt("return", _context9.sent);

            case 13:
            case "end":
              return _context9.stop();
          }
        }
      }, _callee9, this);
    }));

    function getOrderTrades(_x11) {
      return _getOrderTrades.apply(this, arguments);
    }

    return getOrderTrades;
  }();

  _proto.lookupOrders = /*#__PURE__*/function () {
    var _lookupOrders = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee10(_ref9) {
      var oid, oids, origin_ids, endpoint, endpointFinal, queryParams, _queryParams2;

      return runtime_1.wrap(function _callee10$(_context10) {
        while (1) {
          switch (_context10.prev = _context10.next) {
            case 0:
              oid = _ref9.oid, oids = _ref9.oids, origin_ids = _ref9.origin_ids;
              endpoint = 'orders';
              endpointFinal = endpoint;

              if (oid) {
                endpointFinal = endpointFinal.concat('/' + oid);
              } else if (oids) {
                queryParams = new URLSearchParams();
                queryParams.set('oids', oids.join(','));
                endpointFinal = endpointFinal.concat('?' + queryParams);
              } else if (origin_ids) {
                _queryParams2 = new URLSearchParams();

                _queryParams2.set('origin_ids', origin_ids.join(','));

                endpointFinal = endpointFinal.concat('?' + _queryParams2);
              } else {
                endpointFinal = endpoint;
              }

              this._signReq.method = 'GET';
              this._signReq.payload = {};
              this._signReq.endpoint = endpointFinal;
              _context10.next = 9;
              return this._httpClient.get(endpointFinal);

            case 9:
              return _context10.abrupt("return", _context10.sent);

            case 10:
            case "end":
              return _context10.stop();
          }
        }
      }, _callee10, this);
    }));

    function lookupOrders(_x12) {
      return _lookupOrders.apply(this, arguments);
    }

    return lookupOrders;
  }();

  _proto._initializeResponseInterceptor = function _initializeResponseInterceptor() {
    this._httpClient.interceptors.response.use(this._handleResponse, this._handleError);
  };

  return TradeAPI;
}(HttpClient);

var PrivateAPI = function PrivateAPI(_ref) {
  var secret = _ref.secret,
      key = _ref.key,
      version = _ref.version,
      test = _ref.test;
  var Sign = new SigningRequest({
    version: version,
    secret: secret,
    key: key,
    endpoint: '',
    method: '',
    payload: ''
  });
  return {
    Trade: new TradeAPI({
      version: version,
      test: test
    }, Sign),
    Account: new AccountAPI({
      version: version,
      test: test
    }, Sign),
    Funds: new FundsAPI({
      version: version,
      test: test
    }, Sign)
  };
};

var PublicAPI = /*#__PURE__*/function (_HttpClient) {
  _inheritsLoose(PublicAPI, _HttpClient);

  function PublicAPI(_ref) {
    var _this;

    var version = _ref.version,
        test = _ref.test;
    _this = _HttpClient.call(this, test ? "https://api-sandbox.bitso.com"
    /* TEST */
    : "https://api.bitso.com"
    /* PROD */
    + '/' + version) || this;

    _this._handleResponse = function (_ref2) {
      var data = _ref2.data;
      return data.payload;
    };

    _this._handleError = function (error) {
      return Promise.reject(error);
    };

    _this._initializeResponseInterceptor();

    return _this;
  }

  var _proto = PublicAPI.prototype;

  _proto.getAvailableBooks = /*#__PURE__*/function () {
    var _getAvailableBooks = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee() {
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return this._httpClient.get('/available_books');

            case 2:
              return _context.abrupt("return", _context.sent);

            case 3:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function getAvailableBooks() {
      return _getAvailableBooks.apply(this, arguments);
    }

    return getAvailableBooks;
  }();

  _proto.getTicker = /*#__PURE__*/function () {
    var _getTicker = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(book) {
      return runtime_1.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _context2.next = 2;
              return this._httpClient.get('/ticker?book=' + book);

            case 2:
              return _context2.abrupt("return", _context2.sent);

            case 3:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, this);
    }));

    function getTicker(_x) {
      return _getTicker.apply(this, arguments);
    }

    return getTicker;
  }();

  _proto.getOrderBook = /*#__PURE__*/function () {
    var _getOrderBook = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3(book) {
      return runtime_1.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return this._httpClient.get('/order_book?book=' + book);

            case 2:
              return _context3.abrupt("return", _context3.sent);

            case 3:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, this);
    }));

    function getOrderBook(_x2) {
      return _getOrderBook.apply(this, arguments);
    }

    return getOrderBook;
  }();

  _proto.getTrades = /*#__PURE__*/function () {
    var _getTrades = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee4(_ref3) {
      var book, marker, sort, limit, queryParams;
      return runtime_1.wrap(function _callee4$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              book = _ref3.book, marker = _ref3.marker, sort = _ref3.sort, limit = _ref3.limit;
              queryParams = new URLSearchParams();
              if (book) queryParams.set('book', book);
              if (marker) queryParams.set('marker', marker);
              if (sort) queryParams.set('sort', sort);
              if (limit) queryParams.set('limit', limit);
              _context4.next = 8;
              return this._httpClient.get('/trades?' + queryParams);

            case 8:
              return _context4.abrupt("return", _context4.sent);

            case 9:
            case "end":
              return _context4.stop();
          }
        }
      }, _callee4, this);
    }));

    function getTrades(_x3) {
      return _getTrades.apply(this, arguments);
    }

    return getTrades;
  }();

  _proto._initializeResponseInterceptor = function _initializeResponseInterceptor() {
    this._httpClient.interceptors.response.use(this._handleResponse, this._handleError);
  };

  return PublicAPI;
}(HttpClient);

(function (Ticker) {
  Ticker["BTCMXN"] = "btc_mxn";
  Ticker["ETHBTC"] = "eth_btc";
  Ticker["ETHMXN"] = "eth_mxn";
  Ticker["XRPBTC"] = "xrp_btc";
  Ticker["XRPMXN"] = "xrp_mxn";
  Ticker["LTCBTC"] = "ltc_btc";
  Ticker["LTCMXN"] = "ltc_mxn";
  Ticker["BCHBTC"] = "bch_btc";
  Ticker["BCHMXN"] = "bch_mxn";
  Ticker["TUSDBTC"] = "tusd_btc";
  Ticker["TUSDMXN"] = "tusd_mxn";
  Ticker["MANABTC"] = "mana_btc";
  Ticker["BATBTC"] = "bat_btc";
  Ticker["BATMXN"] = "bat_mxn";
  Ticker["BTCARS"] = "btc_ars";
  Ticker["BTCDAI"] = "btc_dai";
  Ticker["DAIMXN"] = "dai_mxn";
  Ticker["BTCUSD"] = "btc_usd";
  Ticker["XRPUSD"] = "xrp_usd";
  Ticker["ETHUSD"] = "eth_usd";
  Ticker["DAIARS"] = "dai_ars";
  Ticker["BTCBRL"] = "btc_brl";
  Ticker["ETHARS"] = "eth_ars";
  Ticker["ETHBRL"] = "eth_brl";
  Ticker["BTCUSDT"] = "btc_usd";
  Ticker["USDMXN"] = "usd_mxn";
  Ticker["USDARS"] = "usd_ars";
  Ticker["USDBRL"] = "usd_brl";
  Ticker["MANAUSD"] = "mana_usd";
  Ticker["LTCUSD"] = "ltc_usd";
  Ticker["COMPUSD"] = "comp_usd";
  Ticker["LINKUSD"] = "link_usd";
  Ticker["UNIUSD"] = "uni_usd";
  Ticker["AAVEUSD"] = "aave_usd";
})(exports.Ticker || (exports.Ticker = {}));

exports.PrivateAPI = PrivateAPI;
exports.PublicAPI = PublicAPI;
exports.SigningRequest = SigningRequest;
//# sourceMappingURL=bitso-ts.cjs.development.js.map
